@@ -14,8 +14,10 @@
 
 #include <QExplicitlySharedDataPointer>
 
-namespace Akonadi {
-namespace Search {
+namespace Akonadi
+{
+namespace Search
+{
 class SearchStore;
 class Result;
 
