@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -9,13 +9,16 @@
 #ifndef AKONADI_SEARCH_PIM_NOTEQUERY_H
 #define AKONADI_SEARCH_PIM_NOTEQUERY_H
 
+#include "query.h"
 #include "search_pim_export.h"
 #include <QString>
-#include "query.h"
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 /**
  * Query for a list of contacts matching a criteria
  */
@@ -23,7 +26,7 @@ class AKONADI_SEARCH_PIM_EXPORT NoteQuery : public Query
 {
 public:
     NoteQuery();
-    ~NoteQuery();
+    ~NoteQuery() override;
 
     void matchTitle(const QString &title);
     void matchNote(const QString &note);
